@@ -2,7 +2,7 @@
   mxTools -- Misc. utilities for Python
 
   Copyright (c) 1997-2000, Marc-Andre Lemburg; mailto:mal@lemburg.com
-  Copyright (c) 2000-2008, eGenix.com Software GmbH; mailto:info@egenix.com
+  Copyright (c) 2000-2009, eGenix.com Software GmbH; mailto:info@egenix.com
   See the documentation for further copyright information or contact
   the author (mailto:mal@lemburg.com).
 
@@ -34,12 +34,18 @@
 /* Needed for mxTools_cur_frame() */
 #include "frameobject.h"
 
-/* Needed for mxTools_dlopen() */
+/* Needed for mxTools_dlopen(); HAVE_DL_LIB is defined by the
+   egenix_mx_base.py setup script if the dl library can be
+   found. HAVE_DLOPEN is defined by Python's configure script, if
+   dlopen() is available. */
+#if defined(HAVE_DL_LIB) && !defined(HAVE_DLOPEN)
+# define HAVE_DLOPEN 1
+#endif
 #ifdef HAVE_DLOPEN
 # include <dlfcn.h>
 #endif
 
-#define MXTOOLS_VERSION "3.1.1"
+#define MXTOOLS_VERSION "3.1.2"
 
 /* To open up the playground for new ideas... */
 /*#define INCLUDE_FUNSTUFF*/
@@ -54,7 +60,7 @@ static char *Module_docstring =
  MXTOOLS_MODULE" -- A tool collection. Version "MXTOOLS_VERSION"\n\n"
 
  "Copyright (c) 1997-2000, Marc-Andre Lemburg; mailto:mal@lemburg.com\n"
- "Copyright (c) 2000-2008, eGenix.com Software GmbH; mailto:info@egenix.com\n\n"
+ "Copyright (c) 2000-2009, eGenix.com Software GmbH; mailto:info@egenix.com\n\n"
  "                 All Rights Reserved\n\n"
  "See the documentation for further information on copyrights,\n"
  "or contact the author."
